Discover Packages
github.com/SlyMarbo/rss/v2
atom1
package
Version:
v2.0.1
Opens a new window with list of versions in this module.
Published: Nov 26, 2025
License: BSD-3-Clause
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Package atom1 provides parsing functionality for Atom feeds.
type Author struct {
Name string `xml:"name"`
URI string `xml:"uri"`
Email string `xml:"email"`
Links []Link `xml:"link"`
}
type Content struct {
RAWContent string `xml:",innerxml"`
}
type Feed struct {
XMLName xml .Name `xml:"feed"`
Title string `xml:"title"`
Description string `xml:"subtitle"`
Author *Author `xml:"author"`
Link []Link `xml:"link"`
Image *Image `xml:"image"`
Items []Item `xml:"entry"`
Updated string `xml:"updated"`
}
Parse decodes data from r as an Atom 1.0 feed.
type Image struct {
XMLName xml .Name `xml:"image"`
Title string `xml:"title"`
URL string `xml:"url"`
Height int `xml:"height"`
Width int `xml:"width"`
}
type Item struct {
XMLName xml .Name `xml:"entry"`
Title string `xml:"title"`
Summary string `xml:"summary"`
Content *Content `xml:"content"`
Links []Link `xml:"link"`
Date string `xml:"updated"`
ID string `xml:"id"`
}
type Link struct {
Href string `xml:"href,attr"`
Rel string `xml:"rel,attr"`
Type string `xml:"type,attr"`
Length uint `xml:"length,attr"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.